/**********************************************************
/* File Browser (Android)                                  *
/*                                                        *
/* Autor:   Roy Schneider                                 *
/*                                                        *
/* Version: 1.0.0                                         *
/*                                                        *
/* Copyright (c) 2012 Roy Schneider (all rights reserved) *
/*                                                        *
/**********************************************************/

// JAVA DOC INFORMATION
/**
@author     Roy Schneider
@see        <a href="http://www.overthehill.de">Author's Homepage</a>
*/

package overthehill.filebrowser_droid;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.view.Window;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

/**
 * Klasse, die die Eingabe eines Datei- oder Ordnernamens realisiert.
 */

public class AppFileName extends Activity {

    public static final String EXTRA_FILE_NAME = "file_name";

    private Button    m_OkButton;
    private Button    m_CancelButton;
    private EditText  m_FileNameEditText;

    private static boolean m_FolderMode;
    private static String  m_Filename;

    /**
     * Methode: Wird aufgerufen, wenn das Activity erstellt wird.
     * 
     * @param Bundle savedInstanceState  Zustand der Anwendung
     */

    @Override

    protected final void onCreate( Bundle savedInstanceState ) {

        /* Basisklasse aufrufen */

        super.onCreate( savedInstanceState );

        /* Dialog erstellen */

        Window w = getWindow();
        w.requestFeature( Window.FEATURE_LEFT_ICON );

        setContentView( R.layout.file_dialog_file );

        w.setFeatureDrawableResource( Window.FEATURE_LEFT_ICON, m_FolderMode ? R.drawable.folder : R.drawable.file );
        setTitle( getString ( m_FolderMode ? R.string.StrFolderActivity : R.string.StrFileActivity ) );

        // Festlegen, was bei ACTION_DONE passieren soll.

        setResult( Activity.RESULT_OK );

        /* Klickt der Anwender "OK", dann den Namen zurckliefern
         * und den Dialog schlieen. */

        m_OkButton = ( Button ) findViewById( R.id.button_ok );
        m_OkButton.setOnClickListener( new OnClickListener() {
            public void onClick( View v ) {
                EndDialog( true );
                return;
            }
        });

        /* Klickt der Anwender "Abbrechen", dann den Dialog abbrechen. */

        m_CancelButton = ( Button ) findViewById( R.id.button_cancel );
        m_CancelButton.setOnClickListener( new OnClickListener() {
            public void onClick( View v ) {
                EndDialog( false );
                return;
            }
        });

        /* Eingabefeld ermitteln. */

        m_FileNameEditText = ( EditText ) findViewById( R.id.edit_filename );

        /* Aktuellen Dateinamen setzen. */

        if ( m_Filename != null ) {
            m_FileNameEditText.setText( m_Filename );
        }

        /* Bei Auswahl der "RETURN"-Taste oder der "CENTER"-Taste, die Eingabe
         * auslesen und den Dialog automatisch beenden lassen. */

        m_FileNameEditText.setOnKeyListener( new EditText.OnKeyListener() {

            @Override

            public boolean onKey( View v, int keyCode, KeyEvent event ) {

                /* Dialog beenden, wenn per Taste gefordert. */

                if ( ( keyCode == KeyEvent.KEYCODE_ENTER ) ||
                     ( keyCode == KeyEvent.KEYCODE_DPAD_CENTER ) ) {

                    EndDialog( true );
                    return ( true );
                }

                return false;
            }
        });

        /* berschrift anpassen (Datei/Ordner) */

        if ( m_FolderMode ) {
            TextView EditCaption = ( TextView ) findViewById( R.id.TextViewFilename );
            EditCaption.setText( R.string.StrFolderName );
        }

        /* Eingabefocus setzen */

        //m_FileNameEditText.requestFocus();
    }

    /**
     * Methode: Wird aufgerufen, um das Activity (Dialog) zu beenden.
     * 
     * @param boolean bok  true, um OK und false um CANCELED zurck zuliefern.
     */

    protected final void EndDialog( boolean bok ) {

        if ( bok ) {

            /* Die Auswahl zurckliefern. */

            String name = m_FileNameEditText.getEditableText().toString();

            name.trim();
            
            if ( name.length() <= 0 ) {
                new AlertDialog.Builder( this ).setIcon( android.R.drawable.ic_menu_info_details )
                .setTitle( m_FolderMode ? R.string.StrNewFolder : R.string.StrRename )
                .setMessage( m_FolderMode ? R.string.StrEnterFoldername : R.string.StrEnterFilename )
                .setPositiveButton( getText( R.string.StrOK ), new DialogInterface.OnClickListener() {

                    @Override

                    public void onClick( DialogInterface dialog, int which ) {
                    }
                }).show();

                return;
            }

            Intent intent = new Intent();
            intent.putExtra( EXTRA_FILE_NAME, name );

            /* Dialog beenden */

            setResult( Activity.RESULT_OK, intent );

            finish();
        } else {

            /* Keine Auswahl zurckliefern. */

            String name = "";

            Intent intent = new Intent();
            intent.putExtra( EXTRA_FILE_NAME, name );

            /* Dialog beenden */

            setResult( Activity.RESULT_CANCELED, intent );

            finish();
        }
    }

    /**
     * Methode: Wird aufgerufen, um vor der Erstellung des Activities
     *          zwischen Datei- und Ordnermodus umzuschalten.
     * 
     * @param boolean bfolder  true, wenn der Name eines Ordners eingegeben werden soll
     */

    public static final void SetFolderMode( boolean bfolder ) {
        m_FolderMode = bfolder;
    }

    /**
     * Methode: Wird aufgerufen, um vor der Erstellung des Activities
     *          den aktuellen Dateinamen zu setzen.
     * 
     * @param String fName  Referenz auf den Dateinamen
     */

    public static void SetFilename( String fName ) {
        m_Filename = fName;
    }


    /**
     * Methode: Wird aufgerufen, wenn eine Taste gedrckt wurde.
     * 
     * @param int keycode     Tastencode ( m_LastKeyPressed.KEYCODE_ )
     * @param KeyEvent event  Ereignisobjekt
     * 
     * @return boolean  true, wenn die Taste vom Programm bereits verarbeitet wurde.
     */
    
    @Override
    
    public boolean onKeyDown ( int keycode, KeyEvent event ) {
    
        /* "Back"-Button behandeln. */

        if ( keycode == KeyEvent.KEYCODE_BACK ) {
            EndDialog( false );
            
            return ( true );
        }
        
        return ( false );
    }
}

/* EoF */
